# /u/sy/beebe/src/psposter/psposter-0.11/prettyprint-encoding.awk, Wed Jan 12 16:48:46 2000
# Edit by Nelson H. F. Beebe <beebe@math.utah.edu>
# ======================================================================
# Prettyprint a PostScript encoding file, adding comments in the
# encoding vector to make it easy to identify each character's
# position.  It is assumed that the encoding vector is defined by
# lines of the form
#
#	/name [
#	...
#	] def
#
# so that tokens within the encoding vector can be readily recognized.
# Existing comments within the encoding vector are discarded, but all
# other comments, and lines outside the encoding vector, are
# preserved.
#
# Usage:
#	awk -f prettyprint-encoding.awk infile >outfile
#
# [12-Jan-2000]
# ======================================================================

BEGIN				{ NChars = 0; InVector = 0 }

/^\/[-A-Za-z0-9]+[ \t]\[/	{ NChars = 0; InVector = 1; print; next }

/^[ \t]*\][ \t]*def/		{ InVector = 0; print; next }

InVector 			{
				    if ($0 ~ "^[ \t]*%")
					next
				    for (k = 1; k <= NF; ++k)
					output($k)
				    next
				}

				{ print }

#=======================================================================

function output(word)
{
    if (NChars == 0)
	Line_Length = 0
    if ((NChars % 16) == 0)
    {
	if (Line_Length > 0)
	    print ""
	printf("    %% \\%03o  %3d  0x%02x\n", NChars, NChars, NChars)
	Line_Length = 0
    }
    if ((NChars % 4) == 0)
    {
	printf("\t")
	Line_Length = 8
    }
    printf("%s%s", word, ((NChars % 4) < 3) ? ((length(word) < 8) ? "\t\t" : "\t") : "")
    Line_Length += 16
    if ((NChars % 4) == 3)
    {
	print ""
	Line_Length = 0
    }
    NChars++
}
